==> json-grep-1.3.0.tar.gz: json-grep-1.3.0/README.md <==
# json-grep

## Description
Simple tool for filtering JSON dict keys from STDOUT

## Usage
```
json-grep --help

usage: json-grep [-h] [-m] [-v] [-l HIGHLIGHT] [-i IHIGHLIGHT] [-e] filter_keys [filter_keys ...]

JSON GREP v1.3.0 is utility for filtering selected keys from json string piped from STDOUT

positional arguments:
  filter_keys           List of keys which you want to filter from json dict. If key is in deeper level of tree structure use '.' separator to specify how deep is key in dict tree structure. You can also use '*' at the end of key name to filter keys as 'beginning with'. You can also specify value of item which you want to pass only by operator '=' or
                        '~'. '~' means that value is somewhere in string.

options:
  -h, --help            show this help message and exit
  -m, --multiline-output
                        Use multiline output for filtered result
  -v, --values_only     Show only values without keys description
  -l HIGHLIGHT, --hl HIGHLIGHT
                        Highlight case sensitively words in filtered results
  -i IHIGHLIGHT, --ihl IHIGHLIGHT
                        Highlight case insensitively words in filtered results
  -e, --show-errors     Show errors caused by json decode
```

## Installation
```bash
wget https://gitlab.com/alda78/json-grep/-/archive/master/json-grep-master.tar && \
tar -xf json-grep-master.tar && \
cd json-grep-master/ && \
sudo python3 setup.py install && \
cd ../ &&  \
sudo rm -rf json-grep-master
```

or simply
```bash
pip3 install json-grep
```

==> json-grep-1.3.1.tar.gz: json-grep-1.3.1/README.md <==
# json-grep

## Description
Simple tool for filtering JSON dict keys from STDOUT

## Usage
```
json-grep --help
usage: json-grep [-h] [-m] [-v] [-l HIGHLIGHT] [-i IHIGHLIGHT] [-e] [-f INPUT_FILE] filter_keys [filter_keys ...]

JSON GREP v1.3.1 is utility for filtering selected keys from json string piped from STDOUT

positional arguments:
  filter_keys           List of keys which you want to filter from json dict. If key is in deeper level of tree structure use '.' separator to specify how deep is key in dict tree structure. You can also use '*' at the end of key name to filter keys as 'beginning with'. You can also specify value of item which you want to pass only by operator '=' or
                        '~'. '~' means that value is somewhere in string.

options:
  -h, --help            show this help message and exit
  -m, --multiline-output
                        Use multiline output for filtered result
  -v, --values_only     Show only values without keys description
  -l HIGHLIGHT, --hl HIGHLIGHT
                        Highlight case sensitively words in filtered results
  -i IHIGHLIGHT, --ihl IHIGHLIGHT
                        Highlight case insensitively words in filtered results
  -e, --show-errors     Show errors caused by json decode
  -f INPUT_FILE, --file INPUT_FILE
                        Input file instead of PIPE
```

## Installation
```bash
wget https://gitlab.com/alda78/json-grep/-/archive/master/json-grep-master.tar && \
tar -xf json-grep-master.tar && \
cd json-grep-master/ && \
sudo python3 setup.py install && \
cd ../ &&  \
sudo rm -rf json-grep-master
```

or simply
```bash
pip3 install json-grep
```
